==> gitlanding-0.0.23.tgz: package/src/Gitlanding.tsx <==
import { GitLandingHeader } from "./GitLandingHeader";
import { GitLandingSection } from "./GitLandingSections";
import { ReviewSlider } from "./ReviewSlider";
import { GitLandingFooter } from "./GitLandingFooter";
import type { GitLandingHeaderProps } from "./GitLandingHeader";
import type { GitLandingSectionProps } from "./GitLandingSections";
import type { GitLandingFooterProps } from "./GitLandingFooter";
import type { Props as ReviewSliderProps } from "./ReviewSlider";
import { ThemeProvider } from "./theme";
import { memo } from "react";

export type GitlandingProps = {
    className?: string;
    header?: GitLandingHeaderProps;
    mainSection?: GitLandingSectionProps;
    reviewSlider?: ReviewSliderProps;
    footer?: GitLandingFooterProps;
};

export const Gitlanding = memo((props: GitlandingProps) => {
    const { footer, header, mainSection, reviewSlider, className } = props;

    return (
        <ThemeProvider>
            <div className={className}>
                {header !== undefined && <GitLandingHeader {...header} />}

                {mainSection !== undefined && (
                    <GitLandingSection
                        className={mainSection.className}
                        sections={mainSection.sections}
                    />
                )}

                {reviewSlider !== undefined && (
                    <ReviewSlider className={reviewSlider.className} reviews={reviewSlider.reviews} />
                )}

                {footer !== undefined && <GitLandingFooter {...footer} />}
            </div>
        </ThemeProvider>
    );
});

==> gitlanding-0.0.25.tgz: package/src/Gitlanding.tsx <==
import { GitLandingHeader } from "./GitLandingHeader";
import { GitLandingSection } from "./GitLandingSections";
import { ReviewSlider } from "./ReviewSlider";
import { GitLandingFooter } from "./GitLandingFooter";
import { ThumbNailSection } from "./ThumbNailSection";
import type { GitLandingHeaderProps } from "./GitLandingHeader";
import type { GitLandingSectionProps } from "./GitLandingSections";
import type { GitLandingFooterProps } from "./GitLandingFooter";
import type { Props as ReviewSliderProps } from "./ReviewSlider";
import type { ThumbNailSectionProps } from "./ThumbNailSection";
import { getThemeApi } from "./theme";
import { useGuaranteedMemo } from "powerhooks/useGuaranteedMemo";
import { memo } from "react";

export type GitlandingProps = {
    className?: string;
    header?: GitLandingHeaderProps;
    mainSection?: GitLandingSectionProps;
    thumbNailSection?: ThumbNailSectionProps;
    reviewSlider?: ReviewSliderProps;
    footer?: GitLandingFooterProps;
};

export const Gitlanding = memo((props: GitlandingProps) => {
    const { thumbNailSection, footer, header, mainSection, reviewSlider, className } = props;

    const { ThemeProvider } = useGuaranteedMemo(() => getThemeApi(), []);

    return (
        <ThemeProvider>
            <div className={className}>
                {header && <GitLandingHeader {...header} />}

                {mainSection && (
                    <GitLandingSection
                        className={mainSection.className}
                        sections={mainSection.sections}
                    />
                )}

                {thumbNailSection && <ThumbNailSection {...thumbNailSection} />}

                {reviewSlider && (
                    <ReviewSlider className={reviewSlider.className} reviews={reviewSlider.reviews} />
                )}

                {footer && <GitLandingFooter {...footer} />}
            </div>
        </ThemeProvider>
    );
});
